@@ -1,4 +1,4 @@
-; <?php exit(); // DO NOT DELETE ?>
+; <?php exit; // DO NOT DELETE?>
 ; DO NOT DELETE THE ABOVE LINE!!!
 ; Doing so will expose this configuration file through your web site!
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -29,7 +29,11 @@
 installed = Off
 
 ; The canonical URL to the OMP installation (excluding the trailing slash)
-base_url = "http://pkp.sfu.ca/omp"
+base_url = "https://pkp.sfu.ca/omp"
+
+; Enable strict mode. This will more aggressively cause errors/warnings when
+; deprecated behaviour exists in the codebase.
+strict = Off
 
 ; Session cookie name
 session_cookie_name = OMPSID
@@ -58,24 +62,18 @@ scheduled_tasks = Off
 scheduled_tasks_report_error_only = On
 
 ; Site time zone
-; Please refer to lib/pkp/registry/timeZones.xml for a full list of supported
+; Please refer to https://www.php.net/timezones for a full list of supported
 ; time zones.
-; I.e.:
-; <entry key="Europe/Amsterdam" name="Amsterdam" />
-; time_zone="Amsterdam"
+; I.e.: "Europe/Amsterdam"
+; time_zone="Europe/Amsterdam"
 time_zone = "UTC"
 
 ; Short and long date formats
-date_format_short = "%Y-%m-%d"
-date_format_long = "%B %e, %Y"
-datetime_format_short = "%Y-%m-%d %I:%M %p"
-datetime_format_long = "%B %e, %Y - %I:%M %p"
-time_format = "%I:%M %p"
-
-; Use URL parameters instead of CGI PATH_INFO. This is useful for broken server
-; setups that don't support the PATH_INFO environment variable.
-; WARNING: This option is DEPRECATED and will be removed in the future.
-disable_path_info = Off
+date_format_short = "Y-m-d"
+date_format_long = "F j, Y"
+datetime_format_short = "Y-m-d h:i A"
+datetime_format_long = "F j, Y - h:i A"
+time_format = "h:i A"
 
 ; Use fopen(...) for URL-based reads. Modern versions of dspace
 ; will not accept requests using fopen, as it does not provide a
@@ -85,14 +83,15 @@ allow_url_fopen = Off
 
 ; Base URL override settings: Entries like the following examples can
 ; be used to override the base URLs used by OMP. If you want to use a
-; proxy to rewrite URLs to OMP, configure your proxy's URL here.
-; Syntax: base_url[press_path] = http://www.myUrl.com
-; To override URLs that aren't part of a particular press, use a
-; press_path of "index".
-; Examples:
-; base_url[index] = http://www.myUrl.com
-; base_url[myPress] = http://www.myUrl.com/myPress
-; base_url[myOtherPress] = http://myOtherPress.myUrl.com
+; proxy to rewrite URLs to OMP, configure your proxy's URL with this format.
+; Syntax: base_url[press_path] = http://www.example.com
+;
+; Example1: URLs that aren't part of a particular press.
+;    Example1: base_url[index] = http://www.example.com
+; Example2: URLs that map to a subdirectory.
+;    Example2: base_url[myPress] = http://www.example.com/myPress
+; Example3: URLs that map to a subdomain.
+;    Example3: base_url[myOtherPress] = http://myOtherPress.example.com
 
 ; Generate RESTful URLs using mod_rewrite.  This requires the
 ; rewrite directive to be enabled in your .htaccess or httpd.conf.
@@ -107,8 +106,7 @@ restful_urls = Off
 allowed_hosts = ''
 
 ; Allow the X_FORWARDED_FOR header to override the REMOTE_ADDR as the source IP
-; Set this to "On" if you are behind a reverse proxy and you control the
-; X_FORWARDED_FOR header.
+; Set this to "On" if you are behind a reverse proxy and you control the X_FORWARDED_FOR
 ; Warning: This defaults to "On" if unset for backwards compatibility.
 trust_x_forwarded_for = Off
 
@@ -121,6 +119,12 @@ enable_minified = On
 ; alert purposes only.
 enable_beacon = On
 
+; The number of days a new user has to validate their account
+; A new user account will be expired and removed if this many days have passed since the user registered
+; their account, and they have not validated their account or logged in. If the user_validation_period is set to
+; 0, unvalidated accounts will never be removed. Use this setting to automatically remove bot registrations.
+user_validation_period = 28
+
 
 ;;;;;;;;;;;;;;;;;;;;;
 ; Database Settings ;
@@ -187,10 +191,7 @@ web_cache_hours = 1
 [i18n]
 
 ; Default locale
-locale = en_US
-
-; Client output/input character set
-client_charset = utf-8
+locale = en
 
 ; Database connection character set
 connection_charset = utf8
@@ -275,28 +276,11 @@ reset_seconds = 7200
 ; stripped.
 allowed_html = "a[href|target|title],em,strong,cite,code,ul,ol,li[class],dl,dt,dd,b,i,u,img[src|alt],sup,sub,br,p"
 
-;Is implicit authentication enabled or not
-
-;implicit_auth = On
-
-;Implicit Auth Header Variables
-
-;implicit_auth_header_first_name = HTTP_TDL_GIVENNAME
-;implicit_auth_header_last_name = HTTP_TDL_SN
-;implicit_auth_header_email = HTTP_TDL_MAIL
-;implicit_auth_header_phone = HTTP_TDL_TELEPHONENUMBER
-;implicit_auth_header_initials = HTTP_TDL_METADATA_INITIALS
-;implicit_auth_header_mailing_address = HTTP_TDL_METADATA_TDLHOMEPOSTALADDRESS
-;implicit_auth_header_uin = HTTP_TDL_TDLUID
-
-; A space delimited list of uins to make admin
-;implicit_auth_admin_list = "100000040@tdl.org 85B7FA892DAA90F7@utexas.edu 100000012@tdl.org"
-
-; URL of the implicit auth 'Way Finder' page. See pages/login/LoginHandler.inc.php for usage.
-
-;implicit_auth_wayf_url = "/Shibboleth.sso/wayf"
-
+; Allowed HTML tags for submission titles only
+; Unspecified attributes will be stripped.
+allowed_title_html = "b,i,u,sup,sub"
 
+;N.b.: The implicit_auth parameter has been removed in favor of plugin implementations such as shibboleth
 
 ;;;;;;;;;;;;;;;;;;
 ; Email Settings ;
@@ -304,6 +288,13 @@ allowed_html = "a[href|target|title],em,strong,cite,code,ul,ol,li[class],dl,dt,d
 
 [email]
 
+; Default method to send emails
+; Available options: sendmail, smtp, log, phpmailer
+default = sendmail
+
+; Path to the sendmail, -bs argument is for using SMTP protocol
+sendmail_path = "/usr/sbin/sendmail -bs"
+
 ; Use SMTP for sending mail instead of mail()
 ; smtp = On
 
@@ -316,21 +307,9 @@ allowed_html = "a[href|target|title],em,strong,cite,code,ul,ol,li[class],dl,dt,d
 ; smtp_auth = ssl
 ; smtp_username = username
 ; smtp_password = password
-;
-; Supported smtp_authtype: RAM-MD5, LOGIN, PLAIN, XOAUTH2 (see PHPMailer AuthType)
-; (Leave blank to try them in that order)
-; smtp_authtype =
 
-; The following are required for smtp_authtype = XOAUTH2 (e.g. GMail OAuth)
-; (See https://github.com/PHPMailer/PHPMailer/wiki/Using-Gmail-with-XOAUTH2)
-; smtp_oauth_provider = Google
-; smtp_oauth_email =
-; smtp_oauth_clientid =
-; smtp_oauth_clientsecret =
-; smtp_oauth_refreshtoken =
-
-; Enable suppressing verification of SMTP certificate in PHPMailer
-; Note: this is not recommended per PHPMailer documentation
+; Enable suppressing SSL/TLS peer verification by SMTP transports
+; Note: this is not recommended for security reasons
 ; smtp_suppress_cert_check = On
 
 ; Allow envelope sender to be specified
@@ -362,14 +341,6 @@ allowed_html = "a[href|target|title],em,strong,cite,code,ul,ol,li[class],dl,dt,d
 ; and '%s' to insert the localized sitename.
 ; dmarc_compliant_from_displayname = '%n via %s'
 
-; Amount of time required between attempts to send non-editorial emails
-; in seconds. This can be used to help prevent email relaying via OMP.
-time_between_emails = 3600
-
-; Maximum number of recipients that can be included in a single email
-; (either as To:, Cc:, or Bcc: addresses) for a non-privileged user
-max_recipients = 10
-
 ; If enabled, email addresses must be validated before login is possible.
 require_validation = Off
 
@@ -423,8 +394,7 @@ result_cache_hours = 1
 ; Enable OAI front-end to the site
 oai = On
 
-; OAI Repository identifier. This setting forms part of OAI-PMH record IDs.
-; Changing this setting may affect existing clients and is not recommended.
+; OAI Repository identifier
 repository_id = omp.pkp.sfu.ca
 
 
@@ -459,6 +429,9 @@ recaptcha = off
 ; Whether or not to use Captcha on user registration
 captcha_on_register = on
 
+; Whether or not to use Captcha on user login
+captcha_on_login = on
+
 ; Validate the hostname in the ReCaptcha response
 recaptcha_enforce_hostname = Off
 
@@ -534,3 +507,61 @@ log_web_service_info = Off
 ; This setting overrides the 'curl.cainfo' parameter of the php.ini configuration file.
 [curl]
 ; cainfo = ""
+
+
+;;;;;;;;;;;;;;;;;;;;;;;
+; Job Queues Settings ;
+;;;;;;;;;;;;;;;;;;;;;;;
+
+[queues]
+
+; Default queue driver
+default_connection = "database"
+
+; Default queue to use when a job is added to the queue
+default_queue = "queue"
+
+; Whether or not to turn on the built-in job runner
+;
+; When enabled, jobs will be processed at the end of each web
+; request to the application.
+;
+; Use of the built-in job runner is highly discouraged for high-volume
+; sites. Instead, a worker daemon or cron job should be configured
+; to process jobs off the application's main thread.
+;
+; See: https://docs.pkp.sfu.ca/admin-guide/en/advanced-jobs
+;
+job_runner = On
+
+; The maximum number of jobs to run in a single request when using
+; the built-in job runner.
+job_runner_max_jobs = 30
+
+; The maximum number of seconds the built-in job runner should spend
+; running jobs in a single request.
+;
+; This should be less than the max_execution_time the server has
+; configured for PHP.
+;
+; Lower this setting if jobs are failing due to timeouts.
+job_runner_max_execution_time = 30
+
+; The maximum consumerable memory that should be spent by the built-in
+; job runner when running jobs.
+;
+; Set as a percentage, such as 80%:
+;
+; job_runner_max_memory = 80
+;
+; Or set as a fixed value in megabytes:
+;
+; job_runner_max_memory = 128M
+;
+; When setting a fixed value in megabytes, this should be less than the
+; memory_limit the server has configured for PHP.
+job_runner_max_memory = 80
+
+; Remove failed jobs from the database after the following number of days.
+; Remove this setting to leave failed jobs in the database.
+delete_failed_jobs_after = 180
